==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Libs/C++/Include/CDPL/ConfGen/FragmentLibraryGenerator.hpp <==
/* 
 * FragmentLibraryGenerator.hpp 
 *
 * This file is part of the ConfGenical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/**
 * \file
 * \brief Definition of the class CDPL::ConfGen::FragmentLibraryGenerator.
 */

#ifndef CDPL_CONFGEN_FRAGMENTLIBRARYGENERATOR_HPP
#define CDPL_CONFGEN_FRAGMENTLIBRARYGENERATOR_HPP

#include <sstream>

#include "CDPL/ConfGen/APIPrefix.hpp"
#include "CDPL/ConfGen/FragmentLibrary.hpp"
#include "CDPL/ConfGen/CanonicalFragment.hpp"
#include "CDPL/ConfGen/FragmentConformerGenerator.hpp"
#include "CDPL/Chem/SMILESMolecularGraphWriter.hpp"


namespace CDPL
{

    namespace ConfGen
    {

        /**
         * \brief FragmentLibraryGenerator.
         */
        class CDPL_CONFGEN_API FragmentLibraryGenerator
        {

          public:
            FragmentLibraryGenerator();

            FragmentLibraryGenerator(const FragmentLibrary::SharedPointer& lib);

            void setFragmentLibrary(const FragmentLibrary::SharedPointer& lib);

            const FragmentLibrary::SharedPointer& getFragmentLibrary() const;

            FragmentConformerGeneratorSettings& getSettings();

            const FragmentConformerGeneratorSettings& getSettings() const;

            void setAbortCallback(const CallbackFunction& func);

            const CallbackFunction& getAbortCallback() const;

            void setTimeoutCallback(const CallbackFunction& func);

            const CallbackFunction& getTimeoutCallback() const;

            void setLogMessageCallback(const LogMessageCallbackFunction& func);

            const LogMessageCallbackFunction& getLogMessageCallback() const;

            unsigned int process(const Chem::MolecularGraph& frag, const Chem::MolecularGraph& parent);

            std::size_t getNumGeneratedConformers() const;

            std::uint64_t getLibraryEntryHashCode() const;

          private:
            FragmentLibraryGenerator(const FragmentLibraryGenerator&);

            FragmentLibraryGenerator& operator=(const FragmentLibraryGenerator&);

            FragmentLibraryEntry::SharedPointer addNewLibraryEntry(const Chem::MolecularGraph& frag, const Chem::MolecularGraph& parent);

            void removeNewLibraryEntry() const;

            void init();

            FragmentLibrary::SharedPointer   fragLib;
            CanonicalFragment                canonFrag;
            FragmentConformerGenerator       fragConfGen;
            std::ostringstream               smilesStream;
            Chem::SMILESMolecularGraphWriter smilesGen;
            std::size_t                      numGenConfs;
        };
    } // namespace ConfGen
} // namespace CDPL

#endif // CDPL_CONFGEN_FRAGMENTLIBRARYGENERATOR_HPP

==> CDPKit-1.2.0.dev1.tar.gz: CDPKit-1.2.0.dev1/Libs/C++/Include/CDPL/ConfGen/FragmentLibraryGenerator.hpp <==
/* 
 * FragmentLibraryGenerator.hpp 
 *
 * This file is part of the ConfGenical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/**
 * \file
 * \brief Definition of the class CDPL::ConfGen::FragmentLibraryGenerator.
 */

#ifndef CDPL_CONFGEN_FRAGMENTLIBRARYGENERATOR_HPP
#define CDPL_CONFGEN_FRAGMENTLIBRARYGENERATOR_HPP

#include <sstream>

#include "CDPL/ConfGen/APIPrefix.hpp"
#include "CDPL/ConfGen/FragmentLibrary.hpp"
#include "CDPL/ConfGen/CanonicalFragment.hpp"
#include "CDPL/ConfGen/FragmentConformerGenerator.hpp"
#include "CDPL/Chem/SMILESMolecularGraphWriter.hpp"


namespace CDPL
{

    namespace ConfGen
    {

        /**
         * \brief FragmentLibraryGenerator.
         */
        class CDPL_CONFGEN_API FragmentLibraryGenerator
        {

          public:
            FragmentLibraryGenerator();

            FragmentLibraryGenerator(const FragmentLibrary::SharedPointer& lib);

            FragmentLibraryGenerator(const FragmentLibraryGenerator&) = delete;

            FragmentLibraryGenerator& operator=(const FragmentLibraryGenerator&) = delete;

            void setFragmentLibrary(const FragmentLibrary::SharedPointer& lib);

            const FragmentLibrary::SharedPointer& getFragmentLibrary() const;

            FragmentConformerGeneratorSettings& getSettings();

            const FragmentConformerGeneratorSettings& getSettings() const;

            void setAbortCallback(const CallbackFunction& func);

            const CallbackFunction& getAbortCallback() const;

            void setTimeoutCallback(const CallbackFunction& func);

            const CallbackFunction& getTimeoutCallback() const;

            void setLogMessageCallback(const LogMessageCallbackFunction& func);

            const LogMessageCallbackFunction& getLogMessageCallback() const;

            unsigned int process(const Chem::MolecularGraph& frag, const Chem::MolecularGraph& parent);

            std::size_t getNumGeneratedConformers() const;

            std::uint64_t getLibraryEntryHashCode() const;

          private:
            FragmentLibraryEntry::SharedPointer addNewLibraryEntry(const Chem::MolecularGraph& frag, const Chem::MolecularGraph& parent);

            void removeNewLibraryEntry() const;

            void init();

            FragmentLibrary::SharedPointer   fragLib;
            CanonicalFragment                canonFrag;
            FragmentConformerGenerator       fragConfGen;
            std::ostringstream               smilesStream;
            Chem::SMILESMolecularGraphWriter smilesGen;
            std::size_t                      numGenConfs;
        };
    } // namespace ConfGen
} // namespace CDPL

#endif // CDPL_CONFGEN_FRAGMENTLIBRARYGENERATOR_HPP
